# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.ansible_collection_version import AnsibleCollectionVersion  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestAnsibleCollectionVersion(unittest.TestCase):
    """AnsibleCollectionVersion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AnsibleCollectionVersion
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.ansible_collection_version.AnsibleCollectionVersion()  # noqa: E501
        if include_optional :
            return AnsibleCollectionVersion(
                artifact = '0', 
                id = '0', 
                authors = [
                    '0'
                    ], 
                contents = [
                    None
                    ], 
                dependencies = None, 
                description = '0', 
                docs_blob = None, 
                manifest = None, 
                files = None, 
                documentation = '0', 
                homepage = '0', 
                issues = '0', 
                license = [
                    '0'
                    ], 
                name = '0', 
                namespace = '0', 
                repository = '0', 
                version = '0', 
                requires_ansible = '0'
            )
        else :
            return AnsibleCollectionVersion(
                artifact = '0',
                id = '0',
                authors = [
                    '0'
                    ],
                contents = [
                    None
                    ],
                dependencies = None,
                description = '0',
                docs_blob = None,
                manifest = None,
                files = None,
                documentation = '0',
                homepage = '0',
                issues = '0',
                license = [
                    '0'
                    ],
                name = '0',
                namespace = '0',
                repository = '0',
                version = '0',
        )

    def testAnsibleCollectionVersion(self):
        """Test AnsibleCollectionVersion"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution import AnsibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution_response import AnsibleAnsibleDistributionResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository import AnsibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository_response import AnsibleAnsibleRepositoryResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote import AnsibleCollectionRemote
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response import AnsibleCollectionRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_response import AnsibleCollectionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version import AnsibleCollectionVersion
from pulpcore.client.pulp_ansible.models.ansible_collection_version_response import AnsibleCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.ansible_repository_sync_url import AnsibleRepositorySyncURL
from pulpcore.client.pulp_ansible.models.ansible_role import AnsibleRole
from pulpcore.client.pulp_ansible.models.ansible_role_remote import AnsibleRoleRemote
from pulpcore.client.pulp_ansible.models.ansible_role_remote_response import AnsibleRoleRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_role_response import AnsibleRoleResponse
from pulpcore.client.pulp_ansible.models.ansible_tag_response import AnsibleTagResponse
from pulpcore.client.pulp_ansible.models.artifact_ref_response import ArtifactRefResponse
from pulpcore.client.pulp_ansible.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_ansible.models.collection_import_detail_response import CollectionImportDetailResponse
from pulpcore.client.pulp_ansible.models.collection_metadata_response import CollectionMetadataResponse
from pulpcore.client.pulp_ansible.models.collection_namespace_response import CollectionNamespaceResponse
from pulpcore.client.pulp_ansible.models.collection_one_shot import CollectionOneShot
from pulpcore.client.pulp_ansible.models.collection_ref_response import CollectionRefResponse
from pulpcore.client.pulp_ansible.models.collection_response import CollectionResponse
from pulpcore.client.pulp_ansible.models.collection_version_docs_response import CollectionVersionDocsResponse
from pulpcore.client.pulp_ansible.models.collection_version_response import CollectionVersionResponse
from pulpcore.client.pulp_ansible.models.content_summary import ContentSummary
from pulpcore.client.pulp_ansible.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_ansible.models.copy import Copy
from pulpcore.client.pulp_ansible.models.galaxy_collection import GalaxyCollection
from pulpcore.client.pulp_ansible.models.galaxy_collection_response import GalaxyCollectionResponse
from pulpcore.client.pulp_ansible.models.galaxy_collection_version_response import GalaxyCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.galaxy_role_response import GalaxyRoleResponse
from pulpcore.client.pulp_ansible.models.galaxy_role_version_response import GalaxyRoleVersionResponse
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list import PaginatedCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links import PaginatedCollectionResponseListLinks
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta import PaginatedCollectionResponseListMeta
from pulpcore.client.pulp_ansible.models.paginated_collection_version_response_list import PaginatedCollectionVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_collection_response_list import PaginatedGalaxyCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_collection_version_response_list import PaginatedGalaxyCollectionVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_response_list import PaginatedGalaxyRoleResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_version_response_list import PaginatedGalaxyRoleVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_tag_response_list import PaginatedTagResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_distribution_response_list import PaginatedansibleAnsibleDistributionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_repository_response_list import PaginatedansibleAnsibleRepositoryResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_remote_response_list import PaginatedansibleCollectionRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_response_list import PaginatedansibleCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_remote_response_list import PaginatedansibleRoleRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_response_list import PaginatedansibleRoleResponseList
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_distribution import PatchedansibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_repository import PatchedansibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.patchedansible_collection_remote import PatchedansibleCollectionRemote
from pulpcore.client.pulp_ansible.models.patchedansible_role_remote import PatchedansibleRoleRemote
from pulpcore.client.pulp_ansible.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_ansible.models.repo_metadata_response import RepoMetadataResponse
from pulpcore.client.pulp_ansible.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_ansible.models.repository_version import RepositoryVersion
from pulpcore.client.pulp_ansible.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_ansible.models.tag_response import TagResponse
from pulpcore.client.pulp_ansible.models.unpaginated_collection_version_response import UnpaginatedCollectionVersionResponse



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedansibleCollectionVersionResponseList(unittest.TestCase):
    """PaginatedansibleCollectionVersionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedansibleCollectionVersionResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list.PaginatedansibleCollectionVersionResponseList()  # noqa: E501
        if include_optional :
            return PaginatedansibleCollectionVersionResponseList(
                count = 123, 
                next = 'http://api.example.org/accounts/?offset=400&limit=100', 
                previous = 'http://api.example.org/accounts/?offset=200&limit=100', 
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/collection_version_response.ansible.CollectionVersionResponse(
                        artifact = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_href = '0', 
                        md5 = '0', 
                        sha1 = '0', 
                        sha224 = '0', 
                        sha256 = '0', 
                        sha384 = '0', 
                        sha512 = '0', 
                        id = '0', 
                        authors = [
                            '0'
                            ], 
                        contents = [
                            None
                            ], 
                        dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                        description = '0', 
                        docs_blob = pulpcore.client.pulp_ansible.models.docs_blob.docs_blob(), 
                        manifest = pulpcore.client.pulp_ansible.models.manifest.manifest(), 
                        files = pulpcore.client.pulp_ansible.models.files.files(), 
                        documentation = '0', 
                        homepage = '0', 
                        issues = '0', 
                        license = [
                            '0'
                            ], 
                        name = '0', 
                        namespace = '0', 
                        repository = '0', 
                        tags = [
                            pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                                name = '0', )
                            ], 
                        version = '0', 
                        requires_ansible = '0', )
                    ]
            )
        else :
            return PaginatedansibleCollectionVersionResponseList(
        )

    def testPaginatedansibleCollectionVersionResponseList(self):
        """Test PaginatedansibleCollectionVersionResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_all_api import PulpAnsibleGalaxyApiV3AllApi  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException


class TestPulpAnsibleGalaxyApiV3AllApi(unittest.TestCase):
    """PulpAnsibleGalaxyApiV3AllApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_all_api.PulpAnsibleGalaxyApiV3AllApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list(self):
        """Test case for list

        """
        pass

    def test_list_0(self):
        """Test case for list_0

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list import PaginatedCollectionResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedCollectionResponseList(unittest.TestCase):
    """PaginatedCollectionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedCollectionResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginated_collection_response_list.PaginatedCollectionResponseList()  # noqa: E501
        if include_optional :
            return PaginatedCollectionResponseList(
                meta = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta.PaginatedCollectionResponseList_meta(
                    count = 123, ), 
                links = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links.PaginatedCollectionResponseList_links(
                    first = '0', 
                    previous = '0', 
                    next = '0', 
                    last = '0', ), 
                data = [
                    pulpcore.client.pulp_ansible.models.collection_response.CollectionResponse(
                        href = '0', 
                        namespace = '0', 
                        name = '0', 
                        deprecated = True, 
                        versions_url = '0', 
                        highest_version = pulpcore.client.pulp_ansible.models.highest_version.highest_version(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else :
            return PaginatedCollectionResponseList(
        )

    def testPaginatedCollectionResponseList(self):
        """Test PaginatedCollectionResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class AnsibleCollectionRemoteResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'name': 'str',
        'url': 'str',
        'ca_cert': 'str',
        'client_cert': 'str',
        'tls_validation': 'bool',
        'proxy_url': 'str',
        'pulp_labels': 'object',
        'pulp_last_updated': 'datetime',
        'download_concurrency': 'int',
        'policy': 'PolicyEnum',
        'total_timeout': 'float',
        'connect_timeout': 'float',
        'sock_connect_timeout': 'float',
        'sock_read_timeout': 'float',
        'headers': 'list[object]',
        'rate_limit': 'int',
        'requirements_file': 'str',
        'auth_url': 'str',
        'token': 'str'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'name': 'name',
        'url': 'url',
        'ca_cert': 'ca_cert',
        'client_cert': 'client_cert',
        'tls_validation': 'tls_validation',
        'proxy_url': 'proxy_url',
        'pulp_labels': 'pulp_labels',
        'pulp_last_updated': 'pulp_last_updated',
        'download_concurrency': 'download_concurrency',
        'policy': 'policy',
        'total_timeout': 'total_timeout',
        'connect_timeout': 'connect_timeout',
        'sock_connect_timeout': 'sock_connect_timeout',
        'sock_read_timeout': 'sock_read_timeout',
        'headers': 'headers',
        'rate_limit': 'rate_limit',
        'requirements_file': 'requirements_file',
        'auth_url': 'auth_url',
        'token': 'token'
    }

    def __init__(self, pulp_href=None, pulp_created=None, name=None, url=None, ca_cert=None, client_cert=None, tls_validation=None, proxy_url=None, pulp_labels=None, pulp_last_updated=None, download_concurrency=None, policy=None, total_timeout=None, connect_timeout=None, sock_connect_timeout=None, sock_read_timeout=None, headers=None, rate_limit=None, requirements_file=None, auth_url=None, token=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleCollectionRemoteResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._name = None
        self._url = None
        self._ca_cert = None
        self._client_cert = None
        self._tls_validation = None
        self._proxy_url = None
        self._pulp_labels = None
        self._pulp_last_updated = None
        self._download_concurrency = None
        self._policy = None
        self._total_timeout = None
        self._connect_timeout = None
        self._sock_connect_timeout = None
        self._sock_read_timeout = None
        self._headers = None
        self._rate_limit = None
        self._requirements_file = None
        self._auth_url = None
        self._token = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.name = name
        self.url = url
        self.ca_cert = ca_cert
        self.client_cert = client_cert
        if tls_validation is not None:
            self.tls_validation = tls_validation
        self.proxy_url = proxy_url
        if pulp_labels is not None:
            self.pulp_labels = pulp_labels
        if pulp_last_updated is not None:
            self.pulp_last_updated = pulp_last_updated
        if download_concurrency is not None:
            self.download_concurrency = download_concurrency
        if policy is not None:
            self.policy = policy
        self.total_timeout = total_timeout
        self.connect_timeout = connect_timeout
        self.sock_connect_timeout = sock_connect_timeout
        self.sock_read_timeout = sock_read_timeout
        if headers is not None:
            self.headers = headers
        self.rate_limit = rate_limit
        self.requirements_file = requirements_file
        self.auth_url = auth_url
        self.token = token

    @property
    def pulp_href(self):
        """Gets the pulp_href of this AnsibleCollectionRemoteResponse.  # noqa: E501


        :return: The pulp_href of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this AnsibleCollectionRemoteResponse.


        :param pulp_href: The pulp_href of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this AnsibleCollectionRemoteResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this AnsibleCollectionRemoteResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def name(self):
        """Gets the name of this AnsibleCollectionRemoteResponse.  # noqa: E501

        A unique name for this remote.  # noqa: E501

        :return: The name of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AnsibleCollectionRemoteResponse.

        A unique name for this remote.  # noqa: E501

        :param name: The name of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def url(self):
        """Gets the url of this AnsibleCollectionRemoteResponse.  # noqa: E501

        The URL of an external content source.  # noqa: E501

        :return: The url of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AnsibleCollectionRemoteResponse.

        The URL of an external content source.  # noqa: E501

        :param url: The url of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def ca_cert(self):
        """Gets the ca_cert of this AnsibleCollectionRemoteResponse.  # noqa: E501

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :return: The ca_cert of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert

    @ca_cert.setter
    def ca_cert(self, ca_cert):
        """Sets the ca_cert of this AnsibleCollectionRemoteResponse.

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :param ca_cert: The ca_cert of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """

        self._ca_cert = ca_cert

    @property
    def client_cert(self):
        """Gets the client_cert of this AnsibleCollectionRemoteResponse.  # noqa: E501

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :return: The client_cert of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._client_cert

    @client_cert.setter
    def client_cert(self, client_cert):
        """Sets the client_cert of this AnsibleCollectionRemoteResponse.

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :param client_cert: The client_cert of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """

        self._client_cert = client_cert

    @property
    def tls_validation(self):
        """Gets the tls_validation of this AnsibleCollectionRemoteResponse.  # noqa: E501

        If True, TLS peer validation must be performed.  # noqa: E501

        :return: The tls_validation of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: bool
        """
        return self._tls_validation

    @tls_validation.setter
    def tls_validation(self, tls_validation):
        """Sets the tls_validation of this AnsibleCollectionRemoteResponse.

        If True, TLS peer validation must be performed.  # noqa: E501

        :param tls_validation: The tls_validation of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: bool
        """

        self._tls_validation = tls_validation

    @property
    def proxy_url(self):
        """Gets the proxy_url of this AnsibleCollectionRemoteResponse.  # noqa: E501

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :return: The proxy_url of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this AnsibleCollectionRemoteResponse.

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :param proxy_url: The proxy_url of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """

        self._proxy_url = proxy_url

    @property
    def pulp_labels(self):
        """Gets the pulp_labels of this AnsibleCollectionRemoteResponse.  # noqa: E501


        :return: The pulp_labels of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: object
        """
        return self._pulp_labels

    @pulp_labels.setter
    def pulp_labels(self, pulp_labels):
        """Sets the pulp_labels of this AnsibleCollectionRemoteResponse.


        :param pulp_labels: The pulp_labels of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: object
        """

        self._pulp_labels = pulp_labels

    @property
    def pulp_last_updated(self):
        """Gets the pulp_last_updated of this AnsibleCollectionRemoteResponse.  # noqa: E501

        Timestamp of the most recent update of the remote.  # noqa: E501

        :return: The pulp_last_updated of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_last_updated

    @pulp_last_updated.setter
    def pulp_last_updated(self, pulp_last_updated):
        """Sets the pulp_last_updated of this AnsibleCollectionRemoteResponse.

        Timestamp of the most recent update of the remote.  # noqa: E501

        :param pulp_last_updated: The pulp_last_updated of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_last_updated = pulp_last_updated

    @property
    def download_concurrency(self):
        """Gets the download_concurrency of this AnsibleCollectionRemoteResponse.  # noqa: E501

        Total number of simultaneous connections.  # noqa: E501

        :return: The download_concurrency of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: int
        """
        return self._download_concurrency

    @download_concurrency.setter
    def download_concurrency(self, download_concurrency):
        """Sets the download_concurrency of this AnsibleCollectionRemoteResponse.

        Total number of simultaneous connections.  # noqa: E501

        :param download_concurrency: The download_concurrency of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                download_concurrency is not None and download_concurrency < 1):  # noqa: E501
            raise ValueError("Invalid value for `download_concurrency`, must be a value greater than or equal to `1`")  # noqa: E501

        self._download_concurrency = download_concurrency

    @property
    def policy(self):
        """Gets the policy of this AnsibleCollectionRemoteResponse.  # noqa: E501

        The policy to use when downloading content.  # noqa: E501

        :return: The policy of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: PolicyEnum
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this AnsibleCollectionRemoteResponse.

        The policy to use when downloading content.  # noqa: E501

        :param policy: The policy of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: PolicyEnum
        """

        self._policy = policy

    @property
    def total_timeout(self):
        """Gets the total_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.total (q.v.) for download-connections.  # noqa: E501

        :return: The total_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_timeout

    @total_timeout.setter
    def total_timeout(self, total_timeout):
        """Sets the total_timeout of this AnsibleCollectionRemoteResponse.

        aiohttp.ClientTimeout.total (q.v.) for download-connections.  # noqa: E501

        :param total_timeout: The total_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                total_timeout is not None and total_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `total_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._total_timeout = total_timeout

    @property
    def connect_timeout(self):
        """Gets the connect_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.connect (q.v.) for download-connections.  # noqa: E501

        :return: The connect_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._connect_timeout

    @connect_timeout.setter
    def connect_timeout(self, connect_timeout):
        """Sets the connect_timeout of this AnsibleCollectionRemoteResponse.

        aiohttp.ClientTimeout.connect (q.v.) for download-connections.  # noqa: E501

        :param connect_timeout: The connect_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                connect_timeout is not None and connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._connect_timeout = connect_timeout

    @property
    def sock_connect_timeout(self):
        """Gets the sock_connect_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections.  # noqa: E501

        :return: The sock_connect_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._sock_connect_timeout

    @sock_connect_timeout.setter
    def sock_connect_timeout(self, sock_connect_timeout):
        """Sets the sock_connect_timeout of this AnsibleCollectionRemoteResponse.

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections.  # noqa: E501

        :param sock_connect_timeout: The sock_connect_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_connect_timeout is not None and sock_connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_connect_timeout = sock_connect_timeout

    @property
    def sock_read_timeout(self):
        """Gets the sock_read_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections.  # noqa: E501

        :return: The sock_read_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: float
        """
        return self._sock_read_timeout

    @sock_read_timeout.setter
    def sock_read_timeout(self, sock_read_timeout):
        """Sets the sock_read_timeout of this AnsibleCollectionRemoteResponse.

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections.  # noqa: E501

        :param sock_read_timeout: The sock_read_timeout of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_read_timeout is not None and sock_read_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_read_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_read_timeout = sock_read_timeout

    @property
    def headers(self):
        """Gets the headers of this AnsibleCollectionRemoteResponse.  # noqa: E501

        Headers for aiohttp.Clientsession  # noqa: E501

        :return: The headers of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: list[object]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this AnsibleCollectionRemoteResponse.

        Headers for aiohttp.Clientsession  # noqa: E501

        :param headers: The headers of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: list[object]
        """

        self._headers = headers

    @property
    def rate_limit(self):
        """Gets the rate_limit of this AnsibleCollectionRemoteResponse.  # noqa: E501

        Limits total download rate in requests per second  # noqa: E501

        :return: The rate_limit of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        """Sets the rate_limit of this AnsibleCollectionRemoteResponse.

        Limits total download rate in requests per second  # noqa: E501

        :param rate_limit: The rate_limit of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: int
        """

        self._rate_limit = rate_limit

    @property
    def requirements_file(self):
        """Gets the requirements_file of this AnsibleCollectionRemoteResponse.  # noqa: E501

        The string version of Collection requirements yaml.  # noqa: E501

        :return: The requirements_file of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._requirements_file

    @requirements_file.setter
    def requirements_file(self, requirements_file):
        """Sets the requirements_file of this AnsibleCollectionRemoteResponse.

        The string version of Collection requirements yaml.  # noqa: E501

        :param requirements_file: The requirements_file of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """

        self._requirements_file = requirements_file

    @property
    def auth_url(self):
        """Gets the auth_url of this AnsibleCollectionRemoteResponse.  # noqa: E501

        The URL to receive a session token from, e.g. used with Automation Hub.  # noqa: E501

        :return: The auth_url of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._auth_url

    @auth_url.setter
    def auth_url(self, auth_url):
        """Sets the auth_url of this AnsibleCollectionRemoteResponse.

        The URL to receive a session token from, e.g. used with Automation Hub.  # noqa: E501

        :param auth_url: The auth_url of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                auth_url is not None and len(auth_url) > 255):
            raise ValueError("Invalid value for `auth_url`, length must be less than or equal to `255`")  # noqa: E501

        self._auth_url = auth_url

    @property
    def token(self):
        """Gets the token of this AnsibleCollectionRemoteResponse.  # noqa: E501

        The token key to use for authentication. See https://docs.ansible.com/ansible/latest/user_guide/collections_using.html#configuring-the-ansible-galaxy-clientfor more details  # noqa: E501

        :return: The token of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AnsibleCollectionRemoteResponse.

        The token key to use for authentication. See https://docs.ansible.com/ansible/latest/user_guide/collections_using.html#configuring-the-ansible-galaxy-clientfor more details  # noqa: E501

        :param token: The token of this AnsibleCollectionRemoteResponse.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                token is not None and len(token) > 2000):
            raise ValueError("Invalid value for `token`, length must be less than or equal to `2000`")  # noqa: E501

        self._token = token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleCollectionRemoteResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleCollectionRemoteResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class ArtifactRefResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'filename': 'str',
        'sha256': 'str',
        'size': 'int'
    }

    attribute_map = {
        'filename': 'filename',
        'sha256': 'sha256',
        'size': 'size'
    }

    def __init__(self, filename=None, sha256=None, size=None, local_vars_configuration=None):  # noqa: E501
        """ArtifactRefResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._filename = None
        self._sha256 = None
        self._size = None
        self.discriminator = None

        self.filename = filename
        self.sha256 = sha256
        self.size = size

    @property
    def filename(self):
        """Gets the filename of this ArtifactRefResponse.  # noqa: E501


        :return: The filename of this ArtifactRefResponse.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this ArtifactRefResponse.


        :param filename: The filename of this ArtifactRefResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and filename is None:  # noqa: E501
            raise ValueError("Invalid value for `filename`, must not be `None`")  # noqa: E501

        self._filename = filename

    @property
    def sha256(self):
        """Gets the sha256 of this ArtifactRefResponse.  # noqa: E501


        :return: The sha256 of this ArtifactRefResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this ArtifactRefResponse.


        :param sha256: The sha256 of this ArtifactRefResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sha256 is None:  # noqa: E501
            raise ValueError("Invalid value for `sha256`, must not be `None`")  # noqa: E501

        self._sha256 = sha256

    @property
    def size(self):
        """Gets the size of this ArtifactRefResponse.  # noqa: E501


        :return: The size of this ArtifactRefResponse.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ArtifactRefResponse.


        :param size: The size of this ArtifactRefResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArtifactRefResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ArtifactRefResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class AnsibleAnsibleRepositoryResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'versions_href': 'str',
        'pulp_labels': 'object',
        'latest_version_href': 'str',
        'name': 'str',
        'description': 'str',
        'remote': 'str',
        'last_synced_metadata_time': 'datetime'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'versions_href': 'versions_href',
        'pulp_labels': 'pulp_labels',
        'latest_version_href': 'latest_version_href',
        'name': 'name',
        'description': 'description',
        'remote': 'remote',
        'last_synced_metadata_time': 'last_synced_metadata_time'
    }

    def __init__(self, pulp_href=None, pulp_created=None, versions_href=None, pulp_labels=None, latest_version_href=None, name=None, description=None, remote=None, last_synced_metadata_time=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleAnsibleRepositoryResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._versions_href = None
        self._pulp_labels = None
        self._latest_version_href = None
        self._name = None
        self._description = None
        self._remote = None
        self._last_synced_metadata_time = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if versions_href is not None:
            self.versions_href = versions_href
        if pulp_labels is not None:
            self.pulp_labels = pulp_labels
        if latest_version_href is not None:
            self.latest_version_href = latest_version_href
        self.name = name
        self.description = description
        self.remote = remote
        self.last_synced_metadata_time = last_synced_metadata_time

    @property
    def pulp_href(self):
        """Gets the pulp_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501


        :return: The pulp_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this AnsibleAnsibleRepositoryResponse.


        :param pulp_href: The pulp_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this AnsibleAnsibleRepositoryResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this AnsibleAnsibleRepositoryResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def versions_href(self):
        """Gets the versions_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501


        :return: The versions_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._versions_href

    @versions_href.setter
    def versions_href(self, versions_href):
        """Sets the versions_href of this AnsibleAnsibleRepositoryResponse.


        :param versions_href: The versions_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: str
        """

        self._versions_href = versions_href

    @property
    def pulp_labels(self):
        """Gets the pulp_labels of this AnsibleAnsibleRepositoryResponse.  # noqa: E501


        :return: The pulp_labels of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: object
        """
        return self._pulp_labels

    @pulp_labels.setter
    def pulp_labels(self, pulp_labels):
        """Sets the pulp_labels of this AnsibleAnsibleRepositoryResponse.


        :param pulp_labels: The pulp_labels of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: object
        """

        self._pulp_labels = pulp_labels

    @property
    def latest_version_href(self):
        """Gets the latest_version_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501


        :return: The latest_version_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._latest_version_href

    @latest_version_href.setter
    def latest_version_href(self, latest_version_href):
        """Sets the latest_version_href of this AnsibleAnsibleRepositoryResponse.


        :param latest_version_href: The latest_version_href of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: str
        """

        self._latest_version_href = latest_version_href

    @property
    def name(self):
        """Gets the name of this AnsibleAnsibleRepositoryResponse.  # noqa: E501

        A unique name for this repository.  # noqa: E501

        :return: The name of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AnsibleAnsibleRepositoryResponse.

        A unique name for this repository.  # noqa: E501

        :param name: The name of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AnsibleAnsibleRepositoryResponse.  # noqa: E501

        An optional description.  # noqa: E501

        :return: The description of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AnsibleAnsibleRepositoryResponse.

        An optional description.  # noqa: E501

        :param description: The description of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def remote(self):
        """Gets the remote of this AnsibleAnsibleRepositoryResponse.  # noqa: E501


        :return: The remote of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this AnsibleAnsibleRepositoryResponse.


        :param remote: The remote of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: str
        """

        self._remote = remote

    @property
    def last_synced_metadata_time(self):
        """Gets the last_synced_metadata_time of this AnsibleAnsibleRepositoryResponse.  # noqa: E501

        Last synced metadata time.  # noqa: E501

        :return: The last_synced_metadata_time of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_synced_metadata_time

    @last_synced_metadata_time.setter
    def last_synced_metadata_time(self, last_synced_metadata_time):
        """Sets the last_synced_metadata_time of this AnsibleAnsibleRepositoryResponse.

        Last synced metadata time.  # noqa: E501

        :param last_synced_metadata_time: The last_synced_metadata_time of this AnsibleAnsibleRepositoryResponse.  # noqa: E501
        :type: datetime
        """

        self._last_synced_metadata_time = last_synced_metadata_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleAnsibleRepositoryResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleAnsibleRepositoryResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulp_ansible.api_client import ApiClient
from pulpcore.client.pulp_ansible.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PulpAnsibleGalaxyApiV2VersionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get(self, name, namespace, path, version, **kwargs):  # noqa: E501
        """get  # noqa: E501

        Return a response to the \"GET\" action.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get(name, namespace, path, version, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param str namespace: (required)
        :param str path: (required)
        :param str version: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_with_http_info(name, namespace, path, version, **kwargs)  # noqa: E501

    def get_with_http_info(self, name, namespace, path, version, **kwargs):  # noqa: E501
        """get  # noqa: E501

        Return a response to the \"GET\" action.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_with_http_info(name, namespace, path, version, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param str namespace: (required)
        :param str path: (required)
        :param str version: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'namespace',
            'path',
            'version',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get`")  # noqa: E501
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `get`")  # noqa: E501
        # verify the required parameter 'path' is set
        if self.api_client.client_side_validation and ('path' not in local_var_params or  # noqa: E501
                                                        local_var_params['path'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `path` when calling `get`")  # noqa: E501
        # verify the required parameter 'version' is set
        if self.api_client.client_side_validation and ('version' not in local_var_params or  # noqa: E501
                                                        local_var_params['version'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `version` when calling `get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'path' in local_var_params:
            path_params['path'] = local_var_params['path']  # noqa: E501
        if 'version' in local_var_params:
            path_params['version'] = local_var_params['version']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/pulp_ansible/galaxy/{path}/api/v2/collections/{namespace}/{name}/versions/{version}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi
from pulpcore.client.pulp_ansible.api.ansible_copy_api import AnsibleCopyApi
from pulpcore.client.pulp_ansible.api.api_collections_api import ApiCollectionsApi
from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi
from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi
from pulpcore.client.pulp_ansible.api.content_collection_versions_api import ContentCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi
from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi
from pulpcore.client.pulp_ansible.api.galaxy_detail_api import GalaxyDetailApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_collections_api import PulpAnsibleGalaxyApiCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v2_versions_api import PulpAnsibleGalaxyApiV2VersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_all_api import PulpAnsibleGalaxyApiV3AllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_api import PulpAnsibleGalaxyApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_docs_blob_api import PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_versions_api import PulpAnsibleGalaxyApiV3VersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_v3_api import PulpAnsibleGalaxyV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_api import RepositoriesAnsibleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_versions_api import RepositoriesAnsibleVersionsApi
from pulpcore.client.pulp_ansible.api.versions_api import VersionsApi



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class CollectionMetadataResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'authors': 'list[str]',
        'contents': 'object',
        'dependencies': 'object',
        'description': 'str',
        'documentation': 'str',
        'homepage': 'str',
        'issues': 'str',
        'license': 'list[str]',
        'repository': 'str',
        'tags': 'list[str]'
    }

    attribute_map = {
        'authors': 'authors',
        'contents': 'contents',
        'dependencies': 'dependencies',
        'description': 'description',
        'documentation': 'documentation',
        'homepage': 'homepage',
        'issues': 'issues',
        'license': 'license',
        'repository': 'repository',
        'tags': 'tags'
    }

    def __init__(self, authors=None, contents=None, dependencies=None, description=None, documentation=None, homepage=None, issues=None, license=None, repository=None, tags=None, local_vars_configuration=None):  # noqa: E501
        """CollectionMetadataResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._authors = None
        self._contents = None
        self._dependencies = None
        self._description = None
        self._documentation = None
        self._homepage = None
        self._issues = None
        self._license = None
        self._repository = None
        self._tags = None
        self.discriminator = None

        if authors is not None:
            self.authors = authors
        if contents is not None:
            self.contents = contents
        if dependencies is not None:
            self.dependencies = dependencies
        if description is not None:
            self.description = description
        if documentation is not None:
            self.documentation = documentation
        if homepage is not None:
            self.homepage = homepage
        if issues is not None:
            self.issues = issues
        if license is not None:
            self.license = license
        if repository is not None:
            self.repository = repository
        self.tags = tags

    @property
    def authors(self):
        """Gets the authors of this CollectionMetadataResponse.  # noqa: E501


        :return: The authors of this CollectionMetadataResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._authors

    @authors.setter
    def authors(self, authors):
        """Sets the authors of this CollectionMetadataResponse.


        :param authors: The authors of this CollectionMetadataResponse.  # noqa: E501
        :type: list[str]
        """

        self._authors = authors

    @property
    def contents(self):
        """Gets the contents of this CollectionMetadataResponse.  # noqa: E501


        :return: The contents of this CollectionMetadataResponse.  # noqa: E501
        :rtype: object
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """Sets the contents of this CollectionMetadataResponse.


        :param contents: The contents of this CollectionMetadataResponse.  # noqa: E501
        :type: object
        """

        self._contents = contents

    @property
    def dependencies(self):
        """Gets the dependencies of this CollectionMetadataResponse.  # noqa: E501


        :return: The dependencies of this CollectionMetadataResponse.  # noqa: E501
        :rtype: object
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this CollectionMetadataResponse.


        :param dependencies: The dependencies of this CollectionMetadataResponse.  # noqa: E501
        :type: object
        """

        self._dependencies = dependencies

    @property
    def description(self):
        """Gets the description of this CollectionMetadataResponse.  # noqa: E501


        :return: The description of this CollectionMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CollectionMetadataResponse.


        :param description: The description of this CollectionMetadataResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def documentation(self):
        """Gets the documentation of this CollectionMetadataResponse.  # noqa: E501


        :return: The documentation of this CollectionMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._documentation

    @documentation.setter
    def documentation(self, documentation):
        """Sets the documentation of this CollectionMetadataResponse.


        :param documentation: The documentation of this CollectionMetadataResponse.  # noqa: E501
        :type: str
        """

        self._documentation = documentation

    @property
    def homepage(self):
        """Gets the homepage of this CollectionMetadataResponse.  # noqa: E501


        :return: The homepage of this CollectionMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._homepage

    @homepage.setter
    def homepage(self, homepage):
        """Sets the homepage of this CollectionMetadataResponse.


        :param homepage: The homepage of this CollectionMetadataResponse.  # noqa: E501
        :type: str
        """

        self._homepage = homepage

    @property
    def issues(self):
        """Gets the issues of this CollectionMetadataResponse.  # noqa: E501


        :return: The issues of this CollectionMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._issues

    @issues.setter
    def issues(self, issues):
        """Sets the issues of this CollectionMetadataResponse.


        :param issues: The issues of this CollectionMetadataResponse.  # noqa: E501
        :type: str
        """

        self._issues = issues

    @property
    def license(self):
        """Gets the license of this CollectionMetadataResponse.  # noqa: E501


        :return: The license of this CollectionMetadataResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this CollectionMetadataResponse.


        :param license: The license of this CollectionMetadataResponse.  # noqa: E501
        :type: list[str]
        """

        self._license = license

    @property
    def repository(self):
        """Gets the repository of this CollectionMetadataResponse.  # noqa: E501


        :return: The repository of this CollectionMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this CollectionMetadataResponse.


        :param repository: The repository of this CollectionMetadataResponse.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def tags(self):
        """Gets the tags of this CollectionMetadataResponse.  # noqa: E501


        :return: The tags of this CollectionMetadataResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CollectionMetadataResponse.


        :param tags: The tags of this CollectionMetadataResponse.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and tags is None:  # noqa: E501
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionMetadataResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionMetadataResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginated_galaxy_collection_version_response_list import PaginatedGalaxyCollectionVersionResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedGalaxyCollectionVersionResponseList(unittest.TestCase):
    """PaginatedGalaxyCollectionVersionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedGalaxyCollectionVersionResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginated_galaxy_collection_version_response_list.PaginatedGalaxyCollectionVersionResponseList()  # noqa: E501
        if include_optional :
            return PaginatedGalaxyCollectionVersionResponseList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    pulpcore.client.pulp_ansible.models.galaxy_collection_version_response.GalaxyCollectionVersionResponse(
                        version = '0', 
                        href = '0', 
                        namespace = pulpcore.client.pulp_ansible.models.namespace.namespace(), 
                        collection = pulpcore.client.pulp_ansible.models.collection.collection(), 
                        artifact = pulpcore.client.pulp_ansible.models.artifact.artifact(), 
                        metadata = pulpcore.client.pulp_ansible.models.collection_metadata_response.CollectionMetadataResponse(
                            authors = [
                                '0'
                                ], 
                            contents = pulpcore.client.pulp_ansible.models.contents.contents(), 
                            dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                            description = '0', 
                            documentation = '0', 
                            homepage = '0', 
                            issues = '0', 
                            license = [
                                '0'
                                ], 
                            repository = '0', 
                            tags = [
                                '0'
                                ], ), )
                    ]
            )
        else :
            return PaginatedGalaxyCollectionVersionResponseList(
        )

    def testPaginatedGalaxyCollectionVersionResponseList(self):
        """Test PaginatedGalaxyCollectionVersionResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
